# Copyright (c) 2016, Camptocamp SA
# All rights reserved.

# Auto-generated file. Do not Edit!
INFO = {
    "git_hash": "3cf36693af4cac30451b81469f72fc218e9432ea",
    "version": "2.0",
    "git_tag": "2.0.0.dev14",
}
